# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainwindow.ui'
#
# Created: Mon May 31 16:40:59 2010
#      by: PyQt4 UI code generator 4.7.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(437, 205)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Fixed, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtGui.QGridLayout(self.centralwidget)
        self.gridLayout.setObjectName("gridLayout")
        self.l_avail = QtGui.QLabel(self.centralwidget)
        font = QtGui.QFont()
        font.setFamily("Sans Serif")
        font.setPointSize(24)
        self.l_avail.setFont(font)
        self.l_avail.setAlignment(QtCore.Qt.AlignCenter)
        self.l_avail.setObjectName("l_avail")
        self.gridLayout.addWidget(self.l_avail, 0, 0, 1, 5)
        self.l_last = QtGui.QLabel(self.centralwidget)
        self.l_last.setAlignment(QtCore.Qt.AlignCenter)
        self.l_last.setObjectName("l_last")
        self.gridLayout.addWidget(self.l_last, 3, 0, 1, 5)
        self.l_solved_1 = QtGui.QLabel(self.centralwidget)
        self.l_solved_1.setObjectName("l_solved_1")
        self.gridLayout.addWidget(self.l_solved_1, 4, 0, 1, 1)
        self.l_solved_2 = QtGui.QLabel(self.centralwidget)
        self.l_solved_2.setObjectName("l_solved_2")
        self.gridLayout.addWidget(self.l_solved_2, 4, 1, 1, 1)
        self.l_solved_3 = QtGui.QLabel(self.centralwidget)
        self.l_solved_3.setObjectName("l_solved_3")
        self.gridLayout.addWidget(self.l_solved_3, 4, 2, 1, 1)
        self.l_solved_4 = QtGui.QLabel(self.centralwidget)
        self.l_solved_4.setObjectName("l_solved_4")
        self.gridLayout.addWidget(self.l_solved_4, 4, 3, 1, 1)
        self.l_solved_5 = QtGui.QLabel(self.centralwidget)
        self.l_solved_5.setObjectName("l_solved_5")
        self.gridLayout.addWidget(self.l_solved_5, 4, 4, 1, 1)
        self.l_typed = QtGui.QLabel(self.centralwidget)
        font = QtGui.QFont()
        font.setFamily("Sans Serif")
        font.setPointSize(24)
        self.l_typed.setFont(font)
        self.l_typed.setAlignment(QtCore.Qt.AlignCenter)
        self.l_typed.setObjectName("l_typed")
        self.gridLayout.addWidget(self.l_typed, 1, 0, 1, 5)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 437, 24))
        self.menubar.setObjectName("menubar")
        self.menuGame = QtGui.QMenu(self.menubar)
        self.menuGame.setObjectName("menuGame")
        self.menuHelp = QtGui.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionAbout = QtGui.QAction(MainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionNew = QtGui.QAction(MainWindow)
        self.actionNew.setObjectName("actionNew")
        self.actionSolve = QtGui.QAction(MainWindow)
        self.actionSolve.setObjectName("actionSolve")
        self.actionQuit = QtGui.QAction(MainWindow)
        self.actionQuit.setObjectName("actionQuit")
        self.actionWordlists = QtGui.QAction(MainWindow)
        self.actionWordlists.setObjectName("actionWordlists")
        self.menuGame.addAction(self.actionNew)
        self.menuGame.addAction(self.actionSolve)
        self.menuGame.addSeparator()
        self.menuGame.addAction(self.actionWordlists)
        self.menuGame.addSeparator()
        self.menuGame.addAction(self.actionQuit)
        self.menuGame.addSeparator()
        self.menuHelp.addAction(self.actionAbout)
        self.menubar.addAction(self.menuGame.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QObject.connect(self.actionQuit, QtCore.SIGNAL("activated()"), MainWindow.close)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Pynagram", None, QtGui.QApplication.UnicodeUTF8))
        self.l_avail.setText(QtGui.QApplication.translate("MainWindow", "ABCDEFG", None, QtGui.QApplication.UnicodeUTF8))
        self.l_last.setText(QtGui.QApplication.translate("MainWindow", "Last Word:", None, QtGui.QApplication.UnicodeUTF8))
        self.l_solved_1.setText(QtGui.QApplication.translate("MainWindow", "Something", None, QtGui.QApplication.UnicodeUTF8))
        self.l_solved_2.setText(QtGui.QApplication.translate("MainWindow", "Something", None, QtGui.QApplication.UnicodeUTF8))
        self.l_solved_3.setText(QtGui.QApplication.translate("MainWindow", "Something", None, QtGui.QApplication.UnicodeUTF8))
        self.l_solved_4.setText(QtGui.QApplication.translate("MainWindow", "Something", None, QtGui.QApplication.UnicodeUTF8))
        self.l_solved_5.setText(QtGui.QApplication.translate("MainWindow", "Something", None, QtGui.QApplication.UnicodeUTF8))
        self.l_typed.setText(QtGui.QApplication.translate("MainWindow", "TUVWXYZ", None, QtGui.QApplication.UnicodeUTF8))
        self.menuGame.setTitle(QtGui.QApplication.translate("MainWindow", "&Game", None, QtGui.QApplication.UnicodeUTF8))
        self.menuHelp.setTitle(QtGui.QApplication.translate("MainWindow", "&Help", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAbout.setText(QtGui.QApplication.translate("MainWindow", "About", None, QtGui.QApplication.UnicodeUTF8))
        self.actionNew.setText(QtGui.QApplication.translate("MainWindow", "New", None, QtGui.QApplication.UnicodeUTF8))
        self.actionNew.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+N", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSolve.setText(QtGui.QApplication.translate("MainWindow", "Solve", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSolve.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+L", None, QtGui.QApplication.UnicodeUTF8))
        self.actionQuit.setText(QtGui.QApplication.translate("MainWindow", "Quit", None, QtGui.QApplication.UnicodeUTF8))
        self.actionQuit.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Q", None, QtGui.QApplication.UnicodeUTF8))
        self.actionWordlists.setText(QtGui.QApplication.translate("MainWindow", "Word Lists", None, QtGui.QApplication.UnicodeUTF8))
        self.actionWordlists.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+O", None, QtGui.QApplication.UnicodeUTF8))

